| api_key | R Documentation |
Allows the user to set and read the api key to be used as default for all functions in this package.
api_key(key)
key |
the api key to be used. The old api key is returned invisibly. |
If api_key() with no arguments, the current value for the api
key is returned or, if it would be ("", the value of the
environmental variable ROriginStamp_api_key is returned. If the
argument key is specified, the api key will be set to the value of
key and the old api key will be returned invisibly.
api_key()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.