View source: R/extract_proof.R
| extract_proof | R Documentation |
If the v verification fails, the function aborts and raises an error.
extract_proof(x, verify = TRUE, verbose = FALSE)
x |
filename or URL pointing either to the xml proof or the pdf certificate issued from OriginStamp. |
verify |
if |
verbose |
if |
the root hash
extract_proof(system.file("certificate.Bitcoin.pdf", package = "ROriginStamp"))
extract_proof(system.file("proof.Bitcoin.xml", package = "ROriginStamp"))
extract_proof(system.file("proof.Bitcoin.xml", package = "ROriginStamp"), verify = FALSE)
######
## These will produce errors when executed
# extract_proof(system.file("proof.faulty.xml", package = "ROriginStamp"))
# extract_proof(system.file("proof.faulty.xml", package = "ROriginStamp"), verbose = TRUE)
######
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.