new_OriginStampResponse: New 'OriginStampResponse' object

View source: R/new_OriginStampResponse.R

new_OriginStampResponseR Documentation

New OriginStampResponse object

Description

Create new OriginStampResponse object. The object contains the following fields:

status

TThe status code of the request. 200 if OK. see https://api.originstamp.com/swagger/swagger-ui.html for details.

content

The returned object, converted into a format suitable for R. The exact format depends on the type of request.

headers

The returned eaders.

Usage

new_OriginStampResponse(response = NULL)

Arguments

response

a response from a call to curl::curl_fetch_memory() which is used to fill the return values of the new object

Value

object of class OriginStampResponse

Examples

x <- new_OriginStampResponse()
x
# $content
# [1] NA
#
# $response
# [1] NA
#
# attr(,"class")
# [1] "OriginStampResponse"

rkrug/ROriginStamp documentation built on Aug. 16, 2022, 5:45 p.m.