transaction_from_txid: Find transaction based on transaction ID

View source: R/transaction_from_txid.R

transaction_from_txidR Documentation

Find transaction based on transaction ID

Description

This function is does not work anymore as the host used is not available anymore! It is only left in to demonstrate how it could be done.

Usage

transaction_from_txid(txid)

Arguments

txid

a vector containing the transaction ids. Usiully only one

Value

a list of the transactions identified by the txid


rkrug/ROriginStamp documentation built on Aug. 16, 2022, 5:45 p.m.