View source: R/new_OriginStampResponse.R
| new_OriginStampResponse | R Documentation |
OriginStampResponse objectCreate new OriginStampResponse object. The object contains the following fields:
TThe status code of the request. 200 if OK. see https://api.originstamp.com/swagger/swagger-ui.html for details.
The returned object, converted into a format suitable for R. The exact format depends on the type of request.
The returned eaders.
new_OriginStampResponse(response = NULL)
response |
a response from a call to |
object of class OriginStampResponse
x <- new_OriginStampResponse() x # $content # [1] NA # # $response # [1] NA # # attr(,"class") # [1] "OriginStampResponse"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.