View source: R/transaction_from_txid.R
| transaction_from_txid | R Documentation |
This function is does not work anymore as the host used is not available anymore! It is only left in to demonstrate how it could be done.
transaction_from_txid(txid)
txid |
a vector containing the transaction ids. Usiully only one |
a list of the transactions identified by the txid
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.